# nolint start
bibentries <- c(
  hamerly2003learning = bibentry(
    "inproceedings",
    title = "Learning the k in k-means",
    author = "Hamerly, Greg and Elkan, Charles",
    booktitle = "Advances in Neural Information Processing Systems",
    editor = "S. Thrun and L. Saul and B. Sch\u00F6lkopf",
    publisher = "MIT Press",
    url = "https://proceedings.neurips.cc/paper_files/paper/2003/file/234833147b97bb6aed53a8f4f1c7a7d8-Paper.pdf",
    volume = "16",
    year = "2003"
  ),
  d2017goodness = bibentry(
    "inbook",
    title = "Goodness-of-Fit-Techniques",
    author = "Stephens, Michael A.",
    editor = "D'Agostino, Ralph B.",
    chapter = "Tests based on EDF statistics",
    year = "1986",
    publisher = "CRC Press"
  ),
  thode2002testing = bibentry(
    "book",
    title = "Testing for normality",
    author = "Thode, Henry C.",
    edition = "1",
    year = "2002",
    publisher = "CRC Press",
    doi = "10.1201/9780203910894"
  ),
  arthur2007kmeanspp = bibentry(
    "inproceedings",
    title = "k-means++: The Advantages of Careful Seeding",
    author = c(person("David", "Arthur"), person("Sergei", "Vassilvitskii")),
    year = "2007",
    booktitle = "Proceedings of the Eighteenth Annual ACM-SIAM Symposium on Discrete Algorithms",
    pages = "1027-1035",
    publisher = "Society for Industrial and Applied Mathematics",
    address = "USA",
    series = "SODA '07",
    isbn = "9780898716245",
    location = "New Orleans, Louisiana"
  )
)
# nolint end
